<script setup>
import AdminAuthenticatedLayout from '@/Layouts/AdminAuthenticatedLayout.vue';
import { ref, onMounted, computed } from 'vue';
import InputError from '@/Components/InputError.vue';
import InputLabel from '@/Components/InputLabel.vue';
import PrimaryButton from '@/Components/PrimaryButton.vue';
import TextInput from '@/Components/TextInput.vue';
import Dropdown from '@/Components/Dropdown.vue';
import { Head, useForm, usePage } from '@inertiajs/vue3';

defineProps({
    status: {
        type: String,
    },
});

const user = usePage().props.auth.user;
console.log(user.id)
const flashMessage = ref('');
const form = useForm({
    name: '',
    company: '',
    contact: '',
    phone: '',
    fax: '',
    address1: '',
    address2: '',
    city: '',
    state: '',
    zip: '',
    country: '',
});

const submit = () => {
    form.post(route('admin.user.address.create',{id: user.id}), {
        onSuccess: () => {
            form.reset()
            // Update your success message or perform other actions here
            flashMessage.value = "User address added successfully!";
        },
        onError: (error) => {
            // Handle error case here, if needed
            console.error(error);
        }
    });
};
</script>

<template>

    <Head title="Add Address" />

    <AdminAuthenticatedLayout>

        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Add Address</h2>
        </template>

        <div class="py-12">
            <div v-if="flashMessage" class="max-w-7xl mx-auto sm:px-6 lg:px-8 font-bold text-green-600">
                <div class="form-row px-8">
                    <div class="col-md-6">
                        <h4>{{ flashMessage }}</h4>
                    </div>
                </div>
            </div>

            <div class="max-w-7xl mx-auto sm:px-6 lg:px-8">
                <form @submit.prevent="submit">
                    <div class="form-row px-8">

                        <div class="mt-4 col-12">
                            <InputLabel for="name" value="Title" />

                            <TextInput
                                id="name"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.name"
                                required
                                autofocus
                                autocomplete="name"
                            />

                            <InputError class="mt-2" :message="form.errors.name" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="company" value="Company" />

                            <TextInput
                                id="company"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.company"
                                required
                                autofocus
                                autocomplete="company"
                            />

                            <InputError class="mt-2" :message="form.errors.company" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="contact" value="Contact" />

                            <TextInput
                                id="contact"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.contact"
                                required
                                autofocus
                                autocomplete="contact"
                            />

                            <InputError class="mt-2" :message="form.errors.contact" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="phone" value="Phone" />

                            <TextInput
                                id="phone"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.phone"
                                required
                                autofocus
                                autocomplete="phone"
                            />

                            <InputError class="mt-2" :message="form.errors.phone" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="fax" value="Fax" />

                            <TextInput
                                id="fax"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.fax"
                                required
                                autofocus
                                autocomplete="fax"
                            />

                            <InputError class="mt-2" :message="form.errors.fax" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="address1" value="Address1" />

                            <TextInput
                                id="address1"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.address1"
                                required
                                autofocus
                                autocomplete="address1"
                            />

                            <InputError class="mt-2" :message="form.errors.address1" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="address2" value="Address2" />

                            <TextInput
                                id="address2"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.address2"
                                autofocus
                                autocomplete="address2"
                            />

                            <InputError class="mt-2" :message="form.errors.address2" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="city" value="City" />

                            <TextInput
                                id="city"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.city"
                                required
                                autofocus
                                autocomplete="city"
                            />

                            <InputError class="mt-2" :message="form.errors.city" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="state" value="State" />

                            <TextInput
                                id="state"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.state"
                                required
                                autofocus
                                autocomplete="state"
                            />

                            <InputError class="mt-2" :message="form.errors.state" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="zip" value="Zip" />

                            <TextInput
                                id="zip"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.zip"
                                required
                                autofocus
                                autocomplete="zip"
                            />

                            <InputError class="mt-2" :message="form.errors.zip" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="country" value="Country" />

                            <TextInput
                                id="country"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.country"
                                required
                                autofocus
                                autocomplete="country"
                            />

                            <InputError class="mt-2" :message="form.errors.country" />
                        </div>

                    </div>

                    <div class="flex items-center justify-end mt-4">
                        <PrimaryButton class="ms-4" :class="{ 'opacity-25': form.processing }" :disabled="form.processing">
                            Add Address
                        </PrimaryButton>
                    </div>
                </form>
            </div>
        </div>
    </AdminAuthenticatedLayout>
</template>
